@@ -13,7 +13,7 @@ class ProperlyEvents(str, Enum):
     USER_ENTERED_ALL_OFFER_INFO = 'userEnteredAllOfferInfo'
     SHOWING_UPDATED_OR_CREATED = 'userShowingUpdatedOrCreated'
     HUBSPOT_DEAL_CHANGED = 'hubspotDealChanged'
-    DEAL_CHANGED = 'dealChanged'
+    DEAL_CHANGED_STAGE = 'dealChangedStage'
     ACCEPTED_OFFER = 'userAcceptedOffer'
     SEARCH_RESULTS_CHANGED = 'searchResultsChanged'
     PPR_FEEDBACK = 'pprFeedback'
